@@ -8,7 +8,7 @@ import {IonSearchbar} from "@ionic/core";
 import {createTransflow, init_wasm, parseAction} from "./quake-core-wrapper";
 
 export interface ActionDefine {
-  object: String,
+  entry: String,
   action: String,
   text: String,
   parameters: String[]
@@ -22,7 +22,7 @@ export interface FlowDefine {
 export interface EntryInfo {
   type: string,
   display: string,
-  properties: any[],
+  properties: object[],
   action: any[],
   flows: FlowDefine[]
 }
@@ -65,6 +65,7 @@ export class QuakeDashboard {
   @State() selected_entry: EntryInfo = null;
   @State() selected_flow_result: Map<string, object[]> = new Map();
   @State() selected_result: any[] = [];
+  @State() selected_entry_file_prop: string = "";
 
   @State() is_flow: boolean = false;
   @State() offset: object = {};
@@ -188,6 +189,15 @@ export class QuakeDashboard {
   async selectType(_e: Event, info: EntryInfo) {
     this.reset_input();
     this.selected_entry = info;
+    this.selected_entry_file_prop = null;
+    for (let property of this.selected_entry.properties) {
+      for (let key in property) {
+        if(property[key] == "File") {
+          this.selected_entry_file_prop = key;
+        }
+      }
+    }
+
     this.query = '/' + info.type + '.';
     this.handleQuery(this);
   }
@@ -282,7 +292,7 @@ export class QuakeDashboard {
 
     const that = this;
     parseAction(this.query.substring(1,)).then(data => {
-      if (data.object) {
+      if (data.entry) {
         that.actionDefine = data
         that.dispatchAction.emit(data);
       } else {
@@ -294,19 +304,23 @@ export class QuakeDashboard {
     });
   }
 
-  editEntry(id: string, object: string) {
+  async showPdf(entry: string, file_prop: string) {
+    await fetch(`/processor/${entry}?file_prop=${file_prop}`)
+  }
+
+  editEntry(id: string, entry: string) {
     this.dispatchAction.emit({
       parameters: [id],
       action: 'update',
-      object: object,
+      entry: entry,
     } as any);
   }
 
-  showEntry(id: string, object: string) {
+  showEntry(id: string, entry: string) {
     this.dispatchAction.emit({
       parameters: [id],
       action: 'show',
-      object: object,
+      entry: entry,
     } as any);
   }
 
@@ -437,6 +451,9 @@ export class QuakeDashboard {
       <ion-card>
         <ion-card-header>
           <ion-card-subtitle># {this.padLeft(item.id, 4, '')}
+            {this.selected_entry_file_prop &&
+              <ion-icon name="document-outline" onClick={() => this.showPdf(type, item[this.selected_entry_file_prop])}/>
+            }
             <ion-icon name="book-outline" onClick={() => this.showEntry(item.id, type)}/>
             <ion-icon name="create-outline" onClick={() => this.editEntry(item.id, type)}/>
           </ion-card-subtitle>
