@@ -17,15 +17,26 @@ use quake_core::usecases::entrysets::Entrysets;
 
 use crate::cli::helper::table_process;
 use crate::helper::exec_wrapper::{editor_exec, meili_exec};
+use crate::usecases::processor_usecases;
 
 pub enum EntryAction {
+    /// add a new entry
     Add,
+    /// dump data to json
     Dump,
+    /// edit entry by index
     Edit,
+    /// feed entry data to search engine
     Feed,
+    /// generate auto content
+    Process,
+    /// list all entry
     List,
+    /// show a entry content
     Show,
+    /// sync entry to csv
     Sync,
+    /// error content
     Error,
 }
 
@@ -36,6 +47,7 @@ impl EntryAction {
             "dump" => EntryAction::Dump,
             "edit" => EntryAction::Edit,
             "feed" => EntryAction::Feed,
+            "process" => EntryAction::Process,
             "list" => EntryAction::List,
             "show" => EntryAction::Show,
             "sync" => EntryAction::Sync,
@@ -45,13 +57,13 @@ impl EntryAction {
 }
 
 pub fn entry_action(expr: &QuakeActionNode, conf: QuakeConfig) -> Result<(), Box<dyn Error>> {
-    let paths = EntryPaths::init(&conf.workspace, &expr.object);
+    let paths = EntryPaths::init(&conf.workspace, &expr.entry);
 
-    // todo: export api for search
     match expr.action.as_str() {
         "add" => {
             let target_file =
-                entry_usecases::create_entry(&conf.workspace, &expr.object, &expr.text)?.0;
+                entry_usecases::create_entry(&conf.workspace, &expr.entry, &expr.text)?.0;
+
             if !conf.editor.is_empty() {
                 editor_exec::edit_file(conf.editor, format!("{:}", target_file.display()))?;
             }
@@ -59,16 +71,21 @@ pub fn entry_action(expr: &QuakeActionNode, conf: QuakeConfig) -> Result<(), Box
             entry_usecases::sync_in_path(&paths)?
         }
         "edit" => {
-            let file =
-                find_entry_path(paths.entry_path, &expr.object, expr.index_from_parameter())?;
+            let file = find_entry_path(paths.entry_path, &expr.entry, expr.index_from_parameter())?;
             if !conf.editor.is_empty() {
                 editor_exec::edit_file(conf.editor, format!("{:}", file.display()))?;
             } else {
                 return Err(Box::new(QuakeError("editor is empty".to_string())));
             }
         }
+        "process" => {
+            process_content(&paths, &expr.entry, false)?;
+        }
+        "process::force" => {
+            process_content(&paths, &expr.entry, true)?;
+        }
         "sync" => entry_usecases::sync_in_path(&paths)?,
-        "feed" => feed_by_path(&paths, &expr.object, &conf)?,
+        "feed" => feed_by_path(&paths, &expr.entry, &conf)?,
         "dump" => dump_by_path(&paths)?,
         "show" => show_entry_detail(expr, &paths)?,
         "list" => show_entrysets(&paths.entry_path.join("entries.csv")),
@@ -88,27 +105,22 @@ fn feed_by_path(
     entry_type: &str,
     conf: &QuakeConfig,
 ) -> Result<(), Box<dyn Error>> {
-    let temp_file = "dump.json";
-
     let defines = EntryDefines::from_path(&paths.entries_define);
     let define = defines
         .find(entry_type)
         .unwrap_or_else(|| panic!("lost entry define for: {:?}", &entry_type));
 
-    let map = Entrysets::jsonify_with_format_date(&paths.entry_path, &define)?.to_string();
-    fs::write(temp_file, map)?;
+    let map = Entrysets::jsonify_with_format_date(&paths.entry_path)?;
 
-    meili_exec::feed_documents(&conf.search_url, entry_type)?;
+    meili_exec::feed_documents(&conf.search_url, entry_type, &map)?;
     meili_exec::feed_settings(&conf.search_url, &define)?;
 
-    fs::remove_file(temp_file)?;
-
     Ok(())
 }
 
 fn show_entry_detail(expr: &QuakeActionNode, paths: &EntryPaths) -> Result<(), Box<dyn Error>> {
     let index = expr.index_from_parameter();
-    let target_file = find_entry_path(paths.entry_path.clone(), &expr.object, index)?;
+    let target_file = find_entry_path(paths.entry_path.clone(), &expr.entry, index)?;
     info!("show file: {:}", &target_file.display());
     let content = fs::read_to_string(target_file)?;
     let file = EntryFile::from(content.as_str(), index)?;
@@ -147,22 +159,36 @@ fn show_entrysets(path: &Path) {
     println!("{}", table);
 }
 
-pub fn dump_by_path(paths: &EntryPaths) -> Result<(), Box<dyn Error>> {
+fn dump_by_path(paths: &EntryPaths) -> Result<(), Box<dyn Error>> {
     let map = Entrysets::jsonify(&paths.entry_path)?;
     fs::write("dump.json", map)?;
     Ok(())
 }
 
+fn process_content(
+    paths: &EntryPaths,
+    entry_type: &str,
+    is_force: bool,
+) -> Result<(), Box<dyn Error>> {
+    let defines = EntryDefines::from_path(&paths.entries_define);
+    if let Some(define) = defines.find(entry_type) {
+        processor_usecases::process_by_path(&define, is_force, &paths.entry_path)?
+    }
+
+    Ok(())
+}
+
 #[cfg(test)]
 mod tests {
-    use quake_core::parser::quake::QuakeActionNode;
-    use quake_core::quake_config::QuakeConfig;
+    use quake_core::quake::QuakeActionNode;
+    use quake_core::QuakeConfig;
 
-    use crate::cli::action;
+    use crate::cli::entry_action::entry_action;
 
+    #[ignore]
     #[test]
-    fn throw_editor_empty() {
-        let expr = QuakeActionNode::from_text("todo.edit(1)").unwrap();
+    fn test_generate_content_for_processors() {
+        let expr = QuakeActionNode::from_text("papers.process").unwrap();
         let config = QuakeConfig {
             editor: "".to_string(),
             workspace: "examples".to_string(),
@@ -171,7 +197,6 @@ mod tests {
             port: 0,
         };
 
-        let expected = action(expr, config).expect_err("cannot process");
-        assert_eq!(format!("{:?}", expected), "QuakeError(\"editor is empty\")");
+        entry_action(&expr, config).unwrap();
     }
 }
