@@ -40,13 +40,14 @@ pub fn quake_action(action: String, conf: &QuakeConfig) -> Result<(), Box<dyn Er
         QuakeAction::Sync => {
             sync_defines(conf)?;
         }
-        QuakeAction::Migration => {}
+        QuakeAction::Migration => {
+            // TBD
+        }
         QuakeAction::Feed => {
             feed_data(conf)?;
         }
         QuakeAction::Refs => {
-            let path = PathBuf::from(&conf.workspace);
-            create_entries_refs(&path)?;
+            create_entries_refs(&PathBuf::from(&conf.workspace))?;
         }
         QuakeAction::Error => {
             return Err(Box::new(QuakeError(format!(
@@ -69,8 +70,6 @@ pub fn is_hidden(entry: &DirEntry) -> bool {
 
 fn feed_data(conf: &QuakeConfig) -> Result<(), Box<dyn Error>> {
     let path = PathBuf::from(&conf.workspace);
-    let temp_file = "dump.json";
-
     let defines = EntryDefines::from_path(&path.join(EntryPaths::entries_define()));
 
     for entry in walk_in_path(path) {
@@ -92,17 +91,14 @@ fn feed_data(conf: &QuakeConfig) -> Result<(), Box<dyn Error>> {
             .find(&entry_type)
             .unwrap_or_else(|| panic!("lost entry define for: {:?}", &entry_type));
 
-        let map = Entrysets::jsonify_with_format_date(&paths.entry_path, &define)?.to_string();
-        fs::write(temp_file, map)?;
+        let map = Entrysets::jsonify_with_format_date(&paths.entry_path)?;
 
-        meili_exec::feed_documents(&conf.search_url, &entry_type)?;
+        meili_exec::feed_documents(&conf.search_url, &entry_type, &map)?;
         meili_exec::feed_settings(&conf.search_url, &define)?;
 
         info!("done '{:}' feed", &entry_type);
     }
 
-    fs::remove_file(temp_file)?;
-
     Ok(())
 }
 
@@ -154,3 +150,26 @@ fn walk_in_path(path: PathBuf) -> FilterEntry<IntoIter, fn(&DirEntry) -> bool> {
         .into_iter()
         .filter_entry(|e| !is_hidden(e))
 }
+
+#[cfg(test)]
+mod tests {
+    use quake_core::parser::quake::QuakeActionNode;
+    use quake_core::quake_config::QuakeConfig;
+
+    use crate::cli::action;
+
+    #[test]
+    fn throw_editor_empty() {
+        let expr = QuakeActionNode::from_text("todo.edit(1)").unwrap();
+        let config = QuakeConfig {
+            editor: "".to_string(),
+            workspace: "examples".to_string(),
+            search_url: "".to_string(),
+            server_location: "".to_string(),
+            port: 0,
+        };
+
+        let expected = action(expr, config).expect_err("cannot process");
+        assert_eq!(format!("{:?}", expected), "QuakeError(\"editor is empty\")");
+    }
+}
