@@ -2,7 +2,7 @@ use crate::helper::exec_wrapper::exec_runner;
 use std::error::Error;
 
 pub fn edit_file(editor: String, file: String) -> Result<(), Box<dyn Error>> {
-    if editor == "~" || editor == "" {
+    if editor == "~" || editor.is_empty() {
         return Ok(());
     }
 
