@@ -1,17 +1,22 @@
 use figment::providers::Yaml;
+use quake_core::entry::EntryDefines;
 use rocket::fairing::AdHoc;
 use rocket::figment::providers::{Env, Format, Serialized};
 use rocket::figment::{Figment, Profile};
 use rocket::fs::FileServer;
-use rocket::{routes, Build, Config, Rocket};
+use rocket::{routes, Build, Config, Rocket, State};
 use serde_derive::{Deserialize, Serialize};
 
+use quake_core::entry::entry_paths::EntryPaths;
 use quake_core::QuakeConfig;
+use std::fs;
+use std::path::PathBuf;
 
 mod action_api;
 mod entry_api;
 mod helper;
 mod layout_api;
+mod processor_api;
 mod reference_api;
 mod transflow_api;
 
@@ -63,10 +68,17 @@ pub fn quake_rocket() -> Rocket<Build> {
             ],
         )
         .mount("/reference", routes![reference_api::reference_by_type])
+        .mount("/processor", routes![processor_api::lookup_file])
         .mount("/layout", routes![layout_api::dashboard_layout])
         .attach(AdHoc::config::<QuakeConfig>())
 }
 
+pub fn defines(config: &State<QuakeConfig>) -> EntryDefines {
+    let path = PathBuf::from(config.workspace.clone()).join(EntryPaths::entries_define());
+    let defines: EntryDefines = serde_yaml::from_str(&*fs::read_to_string(path).unwrap()).unwrap();
+    defines
+}
+
 #[cfg(test)]
 #[allow(unused_imports)]
 mod test {
@@ -89,6 +101,6 @@ mod test {
         let response = client.get("/entry/todo/1").dispatch();
 
         assert_eq!(response.status(), Status::Ok);
-        assert_eq!(response.into_string().unwrap(), "{\"title\":\"time support\",\"author\":\"\",\"content\":\"\",\"created_date\":\"2021-11-24 19:14:10\",\"updated_date\":\"2021-11-24 19:14:10\",\"id\":1,\"content\":\"\\n\\nahaha\\n\"}")
+        assert_eq!(response.into_string().unwrap(), "{\"title\":\"time support\",\"author\":\"\",\"created_date\":\"2021-11-24 19:14:10\",\"updated_date\":\"2021-11-24 19:14:10\",\"id\":1,\"content\":\"\\n\\nahaha\\n\"}")
     }
 }
