@@ -1,4 +1,5 @@
 use std::fs;
+use std::option::Option::None;
 use std::path::PathBuf;
 
 use rocket::fs::NamedFile;
@@ -7,16 +8,18 @@ use rocket::serde::json::Json;
 use rocket::serde::{Deserialize, Serialize};
 use rocket::State;
 use rocket::{get, post};
+use tracing::info;
 
 use quake_core::entry::entry_paths::EntryPaths;
-use quake_core::entry::EntryDefines;
 use quake_core::quake::QuakeTransflowNode;
+use quake_core::transflow::element_define::ElementDefines;
 use quake_core::transflow::js_flow_codegen::JsFlowCodegen;
-use quake_core::transflow::Transflow;
+use quake_core::transflow::{element_define, Transflow};
+use quake_core::usecases::flow_usecases;
 use quake_core::QuakeConfig;
 
+use crate::server;
 use crate::server::ApiError;
-use quake_core::usecases::flow_usecases;
 
 #[derive(Debug, Clone, Deserialize, Serialize)]
 #[serde(crate = "rocket::serde")]
@@ -41,15 +44,26 @@ pub(crate) async fn translate(
         }
     };
 
-    let path = PathBuf::from(config.workspace.clone()).join(EntryPaths::entries_define());
-
-    let content = fs::read_to_string(path).unwrap();
-    let defines: EntryDefines = serde_yaml::from_str(&*content).unwrap();
-
+    let defines = server::defines(config);
     let flow = Transflow::from(defines.entries, node);
-    //
-    let trans = JsFlowCodegen::gen_transform(&flow);
-    let elements = JsFlowCodegen::gen_element(&flow, None);
+
+    let el_path = PathBuf::from(config.workspace.clone())
+        .join(EntryPaths::quake())
+        .join(EntryPaths::element_define());
+
+    let wc = match fs::read_to_string(el_path) {
+        Ok(content) => {
+            let el_def: ElementDefines = serde_yaml::from_str(&*content).unwrap();
+            element_define::filter_element_define(&el_def, &flow.target)
+        }
+        Err(err) => {
+            info!("{:}", err);
+            None
+        }
+    };
+
+    let elements = JsFlowCodegen::gen_element(&flow, &wc);
+    let trans = JsFlowCodegen::gen_transform(&flow, &wc);
 
     let scripts = format!("{:} \n{:}", trans.join("\n"), elements.join("\n"));
 
@@ -110,6 +124,22 @@ mod test {
         assert_eq!(response.status(), Status::Ok);
     }
 
+    #[test]
+    fn transflow_translate_map_script() {
+        let client = Client::tracked(quake_rocket()).expect("valid rocket instance");
+        let url = format!("/transflow/translate/{:}", "show_timeline");
+        let flow = "from('todo','blog').to(<quake-calendar>).map('blog.content => content | uppercase | substring(1, 150)');";
+        let body = format!("{{ \"flow\": {:?} }}", flow);
+
+        let mut response = client.post(url).body(body).dispatch();
+
+        let mut res = "".to_string();
+        let _ = response.read_to_string(&mut res);
+        println!("{:}", res);
+
+        assert_eq!(response.status(), Status::Ok);
+    }
+
     #[test]
     fn transflow_script() {
         let client = Client::tracked(quake_rocket()).expect("valid rocket instance");
@@ -118,6 +148,8 @@ mod test {
         let mut res = "".to_string();
         let _ = response.read_to_string(&mut res);
 
+        println!("{:}", res);
+
         assert_eq!(response.status(), Status::Ok);
     }
 }
